use strict;
use warnings;

package Net::Bugzilla::Kanbanize;
$Net::Bugzilla::Kanbanize::VERSION = '0.006';    # TRIAL

#ABSTRACT: turns baubles into trinkets

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Net::Bugzilla::Kanbanize - turns baubles into trinkets

=head1 VERSION

version 0.006

=head1 SYNOPSIS

Kanbanize Bugzilla Sync Tool

=head1 METHODS

=head2 new

This method does something experimental.

=head2 bar

This method returns a reason.

=head1 AUTHOR

Philippe M. Chiasson <gozer@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2014 by Philippe M. Chiasson.

This is free software, licensed under:

  Mozilla Public License Version 2.0

=cut
